.. automodule:: clients

Client
=============
.. autoclass:: Client
   :show-inheritance:
   :members:
   :special-members: __truediv__

Resource
=============
.. autoclass:: Resource
   :show-inheritance:
   :members:
   :special-members:

   .. function:: content_type(response)

      Return name {*json*, *text*,... } of response's content_type.

Remote
=============
.. autoclass:: Remote
   :show-inheritance:
   :members:
   :special-members:

Graph
=============
.. autoclass:: Graph
   :show-inheritance:
   :members:

Proxy
=============
.. autoclass:: Proxy
   :show-inheritance:
   :members:

AsyncClient
=============
.. autoclass:: AsyncClient
   :show-inheritance:
   :members:
   :special-members: __truediv__

AsyncResource
=============
.. autoclass:: AsyncResource
   :show-inheritance:
   :members:
   :special-members:

AsyncRemote
=============
.. autoclass:: AsyncRemote
   :show-inheritance:
   :members:
   :special-members:

AsyncGraph
=============
.. autoclass:: AsyncGraph
   :show-inheritance:
   :members:

AsyncProxy
=============
.. autoclass:: AsyncProxy
   :show-inheritance:
   :members:

singleton
=============
.. autofunction:: singleton
